pub struct MaskData<'a> {
pub bpp: u8,
pub is_packed: bool,
pub data: &'a [u8],
}Expand description
A single channel alpha mask.
Fields
bpp: u8Number of bits-per-pixel. Always 1, 2, 4 or 8.
is_packed: boolTrue if each row of the data is bit-aligned. Otherwise, each row is padded to the next byte.
data: &'a [u8]Raw bitmap data.
Implementations
Sourceimpl MaskData<'_>
impl MaskData<'_>
Sourcepub fn decode_to_slice(
&self,
width: u32,
height: u32,
dst: &mut [u8],
) -> Result<(), MaskDataDecodeError>
pub fn decode_to_slice( &self, width: u32, height: u32, dst: &mut [u8], ) -> Result<(), MaskDataDecodeError>
Decodes the raw packed bitmap data into 8-bit-per-pixel values, writing the result into the provided buffer.
The buffer must be at least width * height bytes long. Each pixel
value is scaled to the 0–255 range.